==> knative-model-4.12.0-sources.jar: io/fabric8/knative/eventing/v1beta1/EventTypeBuilder.java <==
package io.fabric8.knative.eventing.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class EventTypeBuilder extends EventTypeFluentImpl<EventTypeBuilder> implements VisitableBuilder<EventType,EventTypeBuilder> {

    EventTypeFluent<?> fluent;
    Boolean validationEnabled;

    public EventTypeBuilder() { 
        this(true);
    }


    public EventTypeBuilder(Boolean validationEnabled) { 
        this(new EventType(), validationEnabled);
    }


    public EventTypeBuilder(EventTypeFluent<?> fluent) { 
        this(fluent, true);
    }


    public EventTypeBuilder(EventTypeFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new EventType(), validationEnabled);
    }


    public EventTypeBuilder(EventTypeFluent<?> fluent,EventType instance) { 
        this(fluent, instance, true);
    }


    public EventTypeBuilder(EventTypeFluent<?> fluent,EventType instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withSpec(instance.getSpec()); 
        fluent.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }


    public EventTypeBuilder(EventType instance) { 
        this(instance,true);
    }


    public EventTypeBuilder(EventType instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }


    public EventType build() {
        EventType buildable = new EventType(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        EventTypeBuilder that = (EventTypeBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> knative-model-5.3.1-sources.jar: io/fabric8/knative/eventing/v1beta1/EventTypeBuilder.java <==
package io.fabric8.knative.eventing.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class EventTypeBuilder extends EventTypeFluentImpl<EventTypeBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<EventType,EventTypeBuilder> {

    EventTypeFluent<?> fluent;
    Boolean validationEnabled;

    public EventTypeBuilder() {
        this(true);
    }

    public EventTypeBuilder(Boolean validationEnabled) {
        this(new EventType(), validationEnabled);
    }

    public EventTypeBuilder(EventTypeFluent<?> fluent) {
        this(fluent, true);
    }

    public EventTypeBuilder(EventTypeFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new EventType(), validationEnabled);
    }

    public EventTypeBuilder(EventTypeFluent<?> fluent,EventType instance) {
        this(fluent, instance, true);
    }

    public EventTypeBuilder(EventTypeFluent<?> fluent,EventType instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withSpec(instance.getSpec()); 
        fluent.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public EventTypeBuilder(EventType instance) {
        this(instance,true);
    }

    public EventTypeBuilder(EventType instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.eventing.v1beta1.EditableEventType build() {
        EditableEventType buildable = new EditableEventType(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        EventTypeBuilder that = (EventTypeBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
